@@ -62,7 +62,7 @@
 #define KLEO_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KLEO_NO_DEPRECATED
-#  define KLEO_DISABLE_DEPRECATED_BEFORE_AND_AT 0x60450
+#  define KLEO_DISABLE_DEPRECATED_BEFORE_AND_AT 0x6045a
 #endif
 #ifdef KLEO_NO_DEPRECATED_WARNINGS
 #  define KLEO_DEPRECATED_WARNINGS_SINCE 0
@@ -72,7 +72,7 @@
 #  ifdef KLEO_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KLEO_DEPRECATED_WARNINGS_SINCE KLEO_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KLEO_DEPRECATED_WARNINGS_SINCE 0x60450
+#    define KLEO_DEPRECATED_WARNINGS_SINCE 0x6045a
 #  endif
 #endif
 
